@@ -19,15 +19,9 @@
 #include "kblocks_sound_debug.h"
 #include "settings.h"
 
-KBlocksSound::KBlocksSound()
+KBlocksSound::KBlocksSound(const QString &themeFile)
 {
-    m_blockFallSound = new KgSound(QStandardPaths::locate(
-                    QStandardPaths::AppDataLocation, "sounds/block-fall.ogg"));
-    m_blockMoveSound = new KgSound(QStandardPaths::locate(
-                    QStandardPaths::AppDataLocation, "sounds/block-move.ogg"));
-    m_blockRemoveSound = new KgSound(QStandardPaths::locate(
-                    QStandardPaths::AppDataLocation, "sounds/block-remove.ogg"));
-    setSoundsEnabled(Settings::sounds());
+    loadTheme(themeFile);
 }
 
 KBlocksSound::~KBlocksSound()
@@ -37,6 +31,48 @@ KBlocksSound::~KBlocksSound()
     delete m_blockRemoveSound;
 }
 
+bool KBlocksSound::loadTheme(const QString &themeFile)
+{
+    KGameTheme theme;
+    if (!theme.load(themeFile)) {
+        qCWarning(KBSound) << "Error loading KBlocks .desktop theme"
+                                   << themeFile << endl;
+        theme.loadDefault();
+    }
+
+    QString themeMoveSound;
+    if (theme.themeProperty("Sound_Block_Move") != "") {
+        themeMoveSound = theme.prefix() + theme.themeProperty("Sound_Block_Move");
+    } else {
+        themeMoveSound = QStandardPaths::locate(
+                    QStandardPaths::AppDataLocation, QStringLiteral("sounds/block-move.ogg"));
+    }
+    
+    QString themeFallSound;
+    if (theme.themeProperty("Sound_Block_Fall") != "") {
+        themeFallSound = theme.prefix() + theme.themeProperty("Sound_Block_Fall");
+    } else {
+        themeFallSound = QStandardPaths::locate(
+                    QStandardPaths::AppDataLocation, QStringLiteral("sounds/block-fall.ogg"));
+    }
+    
+    QString themeRemoveSound;
+    if (theme.themeProperty("Sound_Block_Remove") != "") {
+        themeRemoveSound = theme.prefix() + theme.themeProperty("Sound_Block_Remove");
+    } else {
+        themeRemoveSound = QStandardPaths::locate(
+                    QStandardPaths::AppDataLocation, QStringLiteral("sounds/block-remove.ogg"));
+    }
+    
+    delete m_blockFallSound;
+    delete m_blockMoveSound;
+    delete m_blockRemoveSound;
+    m_blockFallSound = new KgSound(themeFallSound);
+    m_blockMoveSound = new KgSound(themeMoveSound);
+    m_blockRemoveSound = new KgSound(themeRemoveSound);
+    return true;
+}
+
 void KBlocksSound::setSoundsEnabled(bool p_enabled)
 {
     sndActive = p_enabled;
